==> ocamldbi-0.9.4.tar.gz: ocamldbi-0.9.4/dbi_mysql.mli <==
(* MySQL database interface for mod_caml programs.
 * Copyright (C) 2003-2004 Merjis Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: dbi_mysql.mli,v 1.2 2004/03/02 16:02:05 rwmj Exp $
 *)

(** Please see {!Dbi} for main documentation. *)

class connection :
  ?host:string ->
  ?port:string ->
  ?user:string ->
  ?password:string ->
  string ->
object
  method close : unit -> unit
  method closed : bool
  method commit : unit -> unit
  method database : string
  method database_type : string
  method debug : bool
  method ex : string -> Dbi.sql_t list -> Dbi.statement
  method host : string option
  method id : int
  method password : string option
  method ping : unit -> bool
  method port : string option
  method prepare : string -> Dbi.statement
  method prepare_cached : string -> Dbi.statement
  method register_postrollback : (unit -> unit) -> Dbi.postrollback_handle
  method register_precommit : (unit -> unit) -> Dbi.precommit_handle
  method rollback : unit -> unit
  method set_debug : bool -> unit
  method unregister_postrollback : Dbi.postrollback_handle -> unit
  method unregister_precommit : Dbi.precommit_handle -> unit
  method user : string option
end

==> ocamldbi-0.9.11.tar.gz: ocamldbi-0.9.11/dbi_mysql.mli <==
(* MySQL database interface for mod_caml programs.
 * Copyright (C) 2003-2004 Merjis Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: dbi_mysql.mli,v 1.3 2004/08/03 16:49:41 rwmj Exp $
 *)

(** Please see {!Dbi} for main documentation. *)

class connection :
  ?host:string ->
  ?port:string ->
  ?user:string ->
  ?password:string ->
  string ->
object
  method close : unit -> unit
  method closed : bool
  method commit : unit -> unit
  method database : string
  method database_type : string
  method debug : bool
  method ex : string -> Dbi.sql_t list -> Dbi.statement
  method host : string option
  method id : int
  method password : string option
  method ping : unit -> bool
  method port : string option
  method prepare : string -> Dbi.statement
  method prepare_cached : string -> Dbi.statement
  method register_postrollback : (unit -> unit) -> Dbi.postrollback_handle
  method register_precommit : (unit -> unit) -> Dbi.precommit_handle
  method rollback : unit -> unit
  method set_debug : bool -> unit
  method unregister_postrollback : Dbi.postrollback_handle -> unit
  method unregister_precommit : Dbi.precommit_handle -> unit
  method user : string option
end

val connect : ?host:string -> ?port:string ->
  ?user:string -> ?password:string -> string -> connection
(** Functional version of [new Dbi.connection ...] *)
val close : connection -> unit
(** Functional version of [dbh#close ()] *)
val closed : connection -> bool
(** Functional version of [dbh#closed] *)
val commit : connection -> unit
(** Functional version of [dbh#commit ()] *)
val ping : connection -> bool
(** Functional version of [dbh#ping ()] *)
val rollback : connection -> unit
(** Functional version of [dbh#rollback ()] *)
